@@ -14,10 +14,10 @@
 # limitations under the License.
 
 import astroid
+import pylint.testutils
 import pytest
 
 import pylint_secure_coding_standard as pylint_scs
-import pylint.testutils
 
 
 class TestSecureCodingStandardChecker(pylint.testutils.CheckerTestCase):
@@ -53,6 +53,12 @@ class TestSecureCodingStandardChecker(pylint.testutils.CheckerTestCase):
             ('from os import system as os_system', 'avoid-os-system'),
             ('from os import popen', 'avoid-os-popen'),
             ('from os import popen as os_popen', 'avoid-os-popen'),
+            ('from subprocess import getoutput', 'avoid-shell-true'),
+            ('from subprocess import getoutput as sp_getoutput', 'avoid-shell-true'),
+            ('from subprocess import getstatusoutput', 'avoid-shell-true'),
+            ('from subprocess import getstatusoutput as sp_getstatusoutput', 'avoid-shell-true'),
+            ('from asyncio import create_subprocess_shell', 'avoid-shell-true'),
+            ('from asyncio import create_subprocess_shell as create_sp_shell', 'avoid-shell-true'),
         ),
     )
     def test_shell_true_importfrom(self, s, msg_id):
@@ -74,6 +80,17 @@ class TestSecureCodingStandardChecker(pylint.testutils.CheckerTestCase):
             ('sp.check_call(["cat", "/etc/passwd"], shell=True)', 'avoid-shell-true'),
             ('subprocess.check_output(["cat", "/etc/passwd"], shell=True)', 'avoid-shell-true'),
             ('sp.check_output(["cat", "/etc/passwd"], shell=True)', 'avoid-shell-true'),
+            ('subprocess.getoutput("ls /bin/ls")', 'avoid-shell-true'),
+            ('sp.getoutput("ls /bin/ls")', 'avoid-shell-true'),
+            ('subprocess.getstatusoutput("ls /bin/ls")', 'avoid-shell-true'),
+            ('sp.getstatusoutput("ls /bin/ls")', 'avoid-shell-true'),
+            ('asyncio.create_subprocess_shell("ls /bin/ls")', 'avoid-shell-true'),
+            ('asyncio.create_subprocess_shell(cmd)', 'avoid-shell-true'),
+            ('asyncio.create_subprocess_shell("ls /bin/ls", stdin=PIPE, stdout=PIPE)', 'avoid-shell-true'),
+            ('asyncio.create_subprocess_shell(cmd, stdin=PIPE, stdout=PIPE)', 'avoid-shell-true'),
+            ('loop.subprocess_shell(asyncio.SubprocessProtocol, "ls /bin/ls")', 'avoid-shell-true'),
+            ('loop.subprocess_shell(asyncio.SubprocessProtocol, cmd)', 'avoid-shell-true'),
+            ('loop.subprocess_shell(asyncio.SubprocessProtocol, cmd, **kwds)', 'avoid-shell-true'),
             ('os.popen("cat")', 'avoid-os-popen'),
             ('os.popen("cat", "r")', 'avoid-os-popen'),
             ('os.popen("cat", "r", 1)', 'avoid-os-popen'),
